@@ -1,4 +1,4 @@
-use crate::{systems::typography::FontSmoothing, TailwindAspect, TailwindBorderCollapse, TailwindBreak, TailwindBuilder, TailwindInstance, ParsedItem, TailwindTableLayout};
+use crate::{systems::typography::FontSmoothing, TailwindAspect, TailwindBorderCollapse, TailwindBreak, TailwindBuilder, TailwindInstance, TailwindTableLayout};
 use nom::{
     bytes::complete::tag,
     character::complete::{alpha1, digit1},
